==> batchcomputecli-0.0.20.tar.gz: batchcomputecli-0.0.20/src/batchcomputecli/actions/project/debug_task.py <==
import json
import os
from ...services import project,config
from terminal import red,prompt,blue


def debug(task_name, docker_image, mount=None):

    type = project.check_is_job_project()

    with open('job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    task = obj['TaskDag']['TaskDescMap'].get(task_name)
    if not task:
        raise Exception('Not found task %s' % task_name)

    job_name = obj.get('JobName')
    local_path = os.path.join(os.getcwd(), 'src')


    oss_host = get_oss_host()

    m = {
        'USER': 'admin',
        'HOME':'/home/admin',
        'ALI_DIKU_INSTANCE_ID': 0,
        'ALI_DIKU_TASK_ID': task_name,
        'ALI_DIKU_JOB_ID':'job-0000000000',
        'ALI_DIKU_JOB_NAME': job_name,
        'ALI_DIKU_OSS_HOST': oss_host
    }


    mount_map = {local_path: '/home/admin'}

    if mount:
        arr = mount.split(',')
        for n in arr:
            arr2 = n.split(':')
            if len(arr2)==2 and arr2[1]!='/home/admin':
                mount_map[arr2[0]]=arr2[1]
    elif task.get('OssMapping'):
        try:
            for (k,v) in task['OssMapping'].items():
                newKey = prompt('Replace oss_path [%s] to a local path for %s' % (blue(k), blue(v)), v)
                if newKey:
                    mount_map[newKey] = v

        except KeyboardInterrupt:
            print('')
            return

    mount_str = ''.join([ (' -v %s:%s' % (k, mount_map[k])) for k in mount_map])


    env_vars = task.get('EnvironmentVariables')
    if env_vars:
        for k in env_vars:
            m[k] = env_vars[k]


    envs = ''.join([ (' -e %s=%s' % (k, m[k]) ) for k in m ])

    if type=='python':
        cmd = """docker run -it %s %s %s python /home/admin/%s %s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')
    elif type=='java':
        cmd = """docker run -it %s %s %s java -jar /home/admin/%s %s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')
    else:
        #native
        cmd = """docker run -it %s %s %s %s /home/admin/%s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')


    print(blue(cmd))

    with os.popen(cmd) as f:
        result = f.read()
        if result:
            print(result)




def get_oss_host():
    opt = config.getConfigs(config.COMMON, ['region','endpoint'])

    if opt.get('region'):
        return 'oss-%s.aliyuncs.com' % opt['region']
    elif opt.get('endpoint'):
        return 'oss-%s.aliyuncs.com' % parse_region_id(opt.get('endpoint'))
    else:
        raise Exception('You need to login first')


def parse_region_id(endpoint):
    return endpoint[len('batchcompute.'): -len('.aliyuncs.com')]

==> batchcomputecli-0.1.3.tar.gz: batchcomputecli-0.1.3/src/batchcomputecli/actions/project/debug_task.py <==
import json
import os
from ...services import project,config
from terminal import red,prompt,blue


def debug(task_name, docker_image, mount=None):

    type = project.check_is_job_project()

    with open('job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    task = obj['TaskDag']['TaskDescMap'].get(task_name)
    if not task:
        raise Exception('Not found task %s' % task_name)

    job_name = obj.get('JobName')
    local_path = os.path.join(os.getcwd(), 'src')


    oss_host = get_oss_host()

    m = {
        'USER': 'admin',
        'HOME':'/home/admin',
        'ALI_DIKU_INSTANCE_ID': 0,
        'ALI_DIKU_TASK_ID': task_name,
        'ALI_DIKU_JOB_ID':'job-0000000000',
        'ALI_DIKU_JOB_NAME': job_name,
        'ALI_DIKU_OSS_HOST': oss_host
    }


    mount_map = {local_path: '/home/admin/worker/'}

    if mount:
        arr = mount.split(',')
        for n in arr:
            arr2 = n.split(':')
            if len(arr2)==2 and arr2[1].startswith('/home/admin/worker'):
                mount_map[arr2[0]]=arr2[1]
    elif task.get('OssMapping'):
        try:
            for (k,v) in task['OssMapping'].items():
                newKey = prompt('Replace oss_path [%s] to a local path for %s' % (blue(k), blue(v)), v)
                if newKey:
                    mount_map[newKey] = v

        except KeyboardInterrupt:
            print('')
            return

    mount_str = ''.join([ (' -v %s:%s' % (k, mount_map[k])) for k in mount_map])


    env_vars = task.get('EnvironmentVariables')
    if env_vars:
        for k in env_vars:
            m[k] = env_vars[k]


    envs = ''.join([ (' -e %s=%s' % (k, m[k]) ) for k in m ])

    if type=='python':
        cmd = """docker run -it %s %s %s python /home/admin/worker/%s %s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')
    elif type=='java':
        cmd = """docker run -it %s %s %s java -jar /home/admin/worker/%s %s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')
    else:
        #native
        cmd = """docker run -it %s %s %s %s /home/admin/worker/%s""" % (
            mount_str, envs, docker_image, task.get('ProgramName'), task.get('ProgramArguments') or '')


    print(blue(cmd))

    with os.popen(cmd) as f:
        result = f.read()
        if result:
            print(result)




def get_oss_host():
    opt = config.getConfigs(config.COMMON, ['region','endpoint'])

    if opt.get('region'):
        return 'oss-%s.aliyuncs.com' % opt['region']
    elif opt.get('endpoint'):
        return 'oss-%s.aliyuncs.com' % parse_region_id(opt.get('endpoint'))
    else:
        raise Exception('You need to login first')


def parse_region_id(endpoint):
    return endpoint[len('batchcompute.'): -len('.aliyuncs.com')]
